==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QMutex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmutex.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QMutex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMutex")
    QMutex *_ptr = reinterpret_cast<QMutex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QMutex()
void __qt_construct_QMutex_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMutex()")
    Q_UNUSED(__java_arguments)
    QMutex *__qt_this = new(__qtjambi_ptr) QMutex();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QMutex
void __qt_destruct_QMutex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMutex")
    reinterpret_cast<QMutex*>(ptr)->~QMutex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMutex::QMutex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMutex_initialize_1native__Lio_qt_core_QMutex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMutex::QMutex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMutex_0, sizeof(QMutex), typeid(QMutex), false, &deleter_QMutex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMutex::tryLock(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMutex_tryLock_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QMutex *__qt_this = QtJambiAPI::objectFromNativeId<QMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMutex::tryLock(int)", __qt_this)
        __java_return_value = __qt_this->tryLock(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMutex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMutex>("QMutex", "io/qt/core/QMutex");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMutex, {
        ConstructorInfo(&__qt_construct_QMutex_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMutex);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QMutex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmutex.h>
#include <QtCore/QVariant>
#include <QtCore/qdeadlinetimer.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QMutex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMutex")
    QMutex *_ptr = reinterpret_cast<QMutex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QMutex()
void __qt_construct_QMutex(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMutex()")
    Q_UNUSED(__java_arguments)
    QMutex *__qt_this = new(__qtjambi_ptr) QMutex();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QMutex::QMutex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMutex_initialize_1native__Lio_qt_core_QMutex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMutex::QMutex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMutex, sizeof(QMutex), typeid(QMutex), false, &deleter_QMutex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMutex
void __qt_destruct_QMutex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMutex")
    reinterpret_cast<QMutex*>(ptr)->~QMutex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMutex::tryLock(QDeadlineTimer)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMutex_tryLock_1native_1QDeadlineTimer__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QMutex *__qt_this = QtJambiAPI::objectFromNativeId<QMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMutex::tryLock(QDeadlineTimer)", __qt_this)
        QDeadlineTimer __qt_timeout0 = QtJambiAPI::valueReferenceFromNativeId<QDeadlineTimer>(timeout0);
        __java_return_value = __qt_this->tryLock(__qt_timeout0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMutex::tryLock(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMutex_tryLock_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QMutex *__qt_this = QtJambiAPI::objectFromNativeId<QMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMutex::tryLock(int)", __qt_this)
        __java_return_value = __qt_this->tryLock(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMutex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMutex>("QMutex", "io/qt/core/QMutex");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMutex, {
        ConstructorInfo(&__qt_construct_QMutex, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMutex);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
